use Test::More;

eval { require Test::Kwalitee; Test::Kwalitee->import(tests => [qw{ -has_meta_yml }]) };

plan( skip_all => 'Test::Kwalitee not installed; skipping' ) if $@;

unlink($_) foreach (<Debian_CPANTS.*>);
